import numpy as np
import matplotlib
from matplotlib import cm
line = cm.Blues_r(10)
band = cm.Blues_r(10,alpha=0.2)

fig_width_pt = 2*246.0  
inches_per_pt = 1.0 / 72.27
golden_mean = (np.sqrt(5) - 1.0) / 2.0
fig_width = fig_width_pt * inches_per_pt
fig_height = fig_width * golden_mean
rect_size = [fig_width, fig_height]

params = {'axes.labelsize': 22,
          'axes.titlesize': 24,
          'font.size': 18,
          'legend.fontsize': 18,
          'font.family': 'serif',
          'font.sans-serif': ['Bitstream Vera Sans'],
          'font.serif': ['Bitstream Vera'],
          'xtick.labelsize': 18,
          'ytick.labelsize': 18,
          'text.usetex': True,
          'text.latex.preamble': r"""\usepackage{amsmath} \usepackage{amssymb} \usepackage{amsfonts}""",
          'figure.figsize': rect_size,
         }

matplotlib.rcParams.update(params)
import matplotlib.pyplot as plt
x, y_line, y_low, y_high = np.loadtxt("sec_3_Figure_2.dat",delimiter=' ').transpose()

fig, ax = plt.subplots(nrows=1, ncols=1, figsize=rect_size) 
ax.loglog(x, y_line, color=line)
ax.fill_between(x, y_low, y_high, color=band)

ax.set_xlim(0.9,100)
ax.set_ylim(1e-6, 1)
ax.set_yticks(np.logspace(-6, 0, 7))

ax.grid(which='both')
ax.set_xlabel(r"Magnification $\mu$")
ax.set_ylabel(r"$\mathit{P}(\geq\mu)$")
fig.set_tight_layout(True)
fig.savefig('./sec_3_Figure_2.pdf', bbox_inches='tight')
